@@ -1,5 +1,5 @@
 package kateb::Install;
-$kateb::Install::VERSION = '01.00.06';
+$kateb::Install::VERSION = '01.00.13';
 
 use strict;
 use warnings;
@@ -29,7 +29,7 @@ my %c =
 );
 
 sub new {
-    my $class      = shift;
+	my $class      = shift;
 	my @args       = @_;
 	my $self;
 	if (not $args[0])
@@ -40,7 +40,7 @@ sub new {
 			errlist => [],
 			fonts   => '',
 		};
-	} elsif ($args[0] =~ /all|-a/) {
+	} elsif ($args[0] =~ /^all$|^-a$/) {
 		$self ={
 			error   => 0,
 			message => "ok!",
@@ -84,7 +84,6 @@ sub install {
 	my $target_dir = $local_data->{targetDir};
 	my $json_file  = $local_data->{jsonFile};
 
-	my @extracted_fonts;
 	foreach my $font_name (@fonts)
 	{
 		my $version = _online_version($info->{$font_name}->{api});
@@ -103,15 +102,16 @@ sub install {
 
 		_download( $url, $archive_file );
 
-		@extracted_fonts =
+		my @extracted_fonts =
 		_unzip($font_name, $archive_file, $cache_dir);
 
 		$local_data->{installedVersions}->{$font_name} = $version;
+
+		_copy_fonts($target_dir, @extracted_fonts) if @extracted_fonts;
+
 		say $c{bgreen} . $font_name . $c{reset} . " installed. version: " . $c{bgreen} . $version . $c{reset};
 	}
 
-	_copy_fonts($target_dir, @extracted_fonts) if @extracted_fonts;
-
 	kateb::LocalData->write_data($local_data->{installedVersions}, $json_file);
 }
 
@@ -126,7 +126,6 @@ sub update {
 	my $target_dir = $local_data->{targetDir};
 	my $json_file  = $local_data->{jsonFile};
 
-	my @extracted_fonts;
 	foreach my $font_name (@fonts)
 	{
 		if (not $local_data->{installedVersions}->{$font_name})
@@ -151,15 +150,16 @@ sub update {
 
 		_download( $url, $archive_file );
 
-		@extracted_fonts =
+		my @extracted_fonts =
 		_unzip($font_name, $archive_file, $cache_dir);
 
 		$local_data->{installedVersions}->{$font_name} = $version;
+
+		_copy_fonts($target_dir, @extracted_fonts) if @extracted_fonts;
+
 		say $c{bgreen} . $font_name . $c{reset} . " updated. version: " . $c{bgreen} . $version . $c{reset};
 	}
 
-	_copy_fonts($target_dir, @extracted_fonts) if @extracted_fonts;
-
 	kateb::LocalData->write_data($local_data->{installedVersions}, $json_file);
 }
 
@@ -174,7 +174,6 @@ sub reinstall {
 	my $target_dir = $local_data->{targetDir};
 	my $json_file  = $local_data->{jsonFile};
 
-	my @extracted_fonts;
 	foreach my $font_name (@fonts)
 	{
 		if (not $local_data->{installedVersions}->{$font_name})
@@ -190,15 +189,16 @@ sub reinstall {
 
 		_download( $url, $archive_file );
 
-		@extracted_fonts =
+		my @extracted_fonts =
 		_unzip($font_name, $archive_file, $cache_dir);
 
 		$local_data->{installedVersions}->{$font_name} = $version;
+
+		_copy_fonts($target_dir, @extracted_fonts) if @extracted_fonts;
+
 		say $c{bgreen} . $font_name . $c{reset} . " installed. version: " . $c{bgreen} . $version . $c{reset};
 	}
 
-	_copy_fonts($target_dir, @extracted_fonts) if @extracted_fonts;
-
 	kateb::LocalData->write_data($local_data->{installedVersions}, $json_file);
 }
 
@@ -285,7 +285,7 @@ sub _unzip {
 			$zip->extractMember( $file, catfile($cache_dir, $file_name) );
 			push @extracted_fonts, catfile($cache_dir, $file_name);
 		}
-	} elsif ($font_name =~ /ganjnameh|nika|mikhak/)
+	} elsif ($font_name =~ /^ganjnameh$|^nika$|^mikhak$|^shahab$/)
 	{
 		foreach my $file (grep { m{.*\.ttf$}g } $zip->memberNames())
 		{
@@ -293,7 +293,7 @@ sub _unzip {
 			$zip->extractMember( $file, catfile($cache_dir, $file_name) );
 			push @extracted_fonts, catfile($cache_dir, $file_name);
 		}
-	} elsif ($font_name =~ /pfont/)
+	} elsif ($font_name =~ /^pfont$/)
 	{
 		foreach my $file (grep { m{(?<!__MACOSX\/)pfont/ttf/Hinted/.*\.ttf$}g } $zip->memberNames())
 		{
@@ -328,8 +328,8 @@ sub _download {
 		env_proxy  => 1,
 	);
 
-	my $file;	   # name of file we download into
-	my $length;	 # total number of bytes to download
+	my $file;	    # name of file we download into
+	my $length;	    # total number of bytes to download
 	my $flength;	# formatted length
 	my $size = 0;   # number of bytes received
 	my $start_t;	# start time of download
@@ -492,5 +492,3 @@ BEGIN {
 
 
 1;
-
-
